// *****************************************************************************
//! \file        
//! \author      Val Controls A/S \n
//!              Jrgen Johannessen & Stefan Greisen\n
//!              Last edited by: \$Author: Stefan Greisen$
//! \date        Initial version 8-10-2009
//!              Last edited date: \$Date: 09-09-2014 15:07:26$
//! \version     1-00-00 \$Revision: 8$
//!              Compiler: DD-IDE v. 4.1\n
//! \brief       Function: DD for the IVC
//! \brief       DVC-SW-005 - HART dd file for IVC24
// *****************************************************************************


/*****************************************************************************
 * The manufacturer line
 *****************************************************************************
 */

//MANUFACTURER 0x00602E, DEVICE_TYPE 0xE1F0, DEVICE_REVISION 1, DD_REVISION 2 // Til Siemens PDM 6
MANUFACTURER Val_Controls_AS, DEVICE_TYPE _IVC24, DEVICE_REVISION 1, DD_REVISION 2


/*****************************************************************************
 * Include Files
 *****************************************************************************
 */

#include "macros.h"
#include "methods.h"

// Include the Device Variable definitions
#include "IVC24_deviceVariable.ddl"

/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */
 
/*****************************************************************************
 * Common Tables
 */
//IMPORT STANDARD _TABLES, DEVICE_REVISION 17, DD_REVISION 1 // Til Siemens PDM 6
IMPORT STANDARD _TABLES, DEVICE_REVISION 20, DD_REVISION 4
{
    EVERYTHING;
        /*
         * This must be redefined if the Manufacturer is not listed
         * in the Common Tables DD
         */

    /*********************************************************************************
     * Val Controls A/S Device Type Codes
     */


    
    REDEFINITIONS
    {

        REDEFINE VARIABLE device_type
        {
            LABEL [device_type];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED (2)
            {
                { 0xE1F0,  "IVC24" }
            }
        }

        /*
        REDEFINE VARIABLE device_name
        {
            LABEL [device_name];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED (2)
            {
                { 0xE0D5,  "IVC24" }
            }
        }
        */

        VARIABLE manufacturer_expansion_model_code    // 0x00E0 
        {
            REDEFINE CLASS LOCAL;
            REDEFINE TYPE ENUMERATED (2)
            {
                { 0x00D5, [ihp]   },
                { 0x00D6, [idp]   },
                { 0x00CF, "IHP24" }, // IHP24 (SG) 01-09-2014
                { 0x00F0, "IVC24" }  // IVC24 (SG) 01-09-2014
            }
        }

        VARIABLE device_type_code
        {
            REDEFINE CLASS LOCAL;
            REDEFINE TYPE ENUMERATED (2)
            {
                { 0xE0D5,  Val_Controls_AS_model_code(0xE0D5) },
                { 0xE0D6,  Val_Controls_AS_model_code(0xE0D6) }, 
                { 0xE1CF,  Val_Controls_AS_model_code(0xE1CF) }, // 0xE1CF (SG) 01-09-2014 
                { 0xE1F0,  Val_Controls_AS_model_code(0xE1F0) }  // 0xE1F0 (SG) 01-09-2014 
            }
        }
        
        VARIABLE Val_Controls_AS_model_code    // 0x602E 
        {
            REDEFINE CLASS LOCAL;
            REDEFINE TYPE ENUMERATED (2)
            {        
                { 0xE0D5, [ihp]   },
                { 0xE0D6, [idp]   },
                { 0xE1CF, "IHP24" }, // IHP24(SG) 01-09-2014
                { 0xE1F0, "IVC24" }  // IVC24 (SG) 01-09-2014
            }
        }
    }

}

/*****************************************************************************
 * Universal Commmands
 */
IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 7, DD_REVISION 2
{
    // All HART devices must support all Universal Commands
    EVERYTHING;

    REDEFINITIONS
    {

        /* 
         * The transaction will need to be redefine to show the correct
         * number of dynamic variables returned in this command 
         * (Command 3) 
         */
        COMMAND read_dynamic_variables_and_pv_current
        {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status,
                    PV.DAQ.ANALOG_VALUE,
                    PV.DEVICE_VARIABLE.DIGITAL_UNITS, PV.DEVICE_VARIABLE.DIGITAL_VALUE,
                    SV.DEVICE_VARIABLE.DIGITAL_UNITS, SV.DEVICE_VARIABLE.DIGITAL_VALUE
                    TV.DEVICE_VARIABLE.DIGITAL_UNITS, TV.DEVICE_VARIABLE.DIGITAL_VALUE,
                    QV.DEVICE_VARIABLE.DIGITAL_UNITS, QV.DEVICE_VARIABLE.DIGITAL_VALUE
                }
            }
        }
        

        /* 
         * The transaction will need to be redefine to show the correct
         * number of dynamic variables returned in this command 
         * (Command 8)
         */
        COMMAND read_dynamic_variable_classification
        {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status,
                    PV.DEVICE_VARIABLE.CLASSIFICATION,
                    SV.DEVICE_VARIABLE.CLASSIFICATION,
                    TV.DEVICE_VARIABLE.CLASSIFICATION,
                    QV.DEVICE_VARIABLE.CLASSIFICATION
                }
            }
        }

        // COMMAND 9
        // Deactivated due to error i error log for SDC625
        COMMAND read_device_variables_and_status
        {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status

                }
            }
        }

        DELETE VARIABLE device_specific_status_14;
        DELETE VARIABLE device_specific_status_15;
        DELETE VARIABLE device_specific_status_16;
        DELETE VARIABLE device_specific_status_17;
        DELETE VARIABLE device_specific_status_18;
        DELETE VARIABLE device_specific_status_19;
        DELETE VARIABLE device_specific_status_20;
        DELETE VARIABLE device_specific_status_21;
        DELETE VARIABLE device_specific_status_22;
        DELETE VARIABLE device_specific_status_23;
        DELETE VARIABLE device_specific_status_24;

        // Remove the command 48 status bytes that are not supported by the device
        // See also command 48 related items in the common practice imports.
        COMMAND read_additional_device_status
        {
            REDEFINE TRANSACTION 0
            {
                REQUEST
                {}
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0, device_specific_status_1, device_specific_status_2,
                    device_specific_status_3, device_specific_status_4, device_specific_status_5,

                    extended_fld_device_status, 0x00
                }
            }

            REDEFINE TRANSACTION 1
            {
                REQUEST
                {
                    device_specific_status_0 (INFO), device_specific_status_1 (INFO), device_specific_status_2 (INFO),
                    device_specific_status_3 (INFO), device_specific_status_4 (INFO), device_specific_status_5 (INFO),

                    extended_fld_device_status (INFO), 0x00
                }
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0, device_specific_status_1, device_specific_status_2,
                    device_specific_status_3, device_specific_status_4, device_specific_status_5,

                    extended_fld_device_status, 0x00
                }
            }
        }
    }
}

/*****************************************************************************
 * PV, when the primary variable is not mappable we can import the PV
 * standard DD to take care of the dynamic variable array, loop current
 * and ranging functions
 */

IMPORT STANDARD _PV, DEVICE_REVISION 1, DD_REVISION 1
{
    EVERYTHING;

    REDEFINITIONS
    {

        /* 
         * Most devices use the same data item for range units (command 15) and the sensor units.
         * when this is true the following should be added.  if your device uses a different variable
         * for range units you should reference it here 
         */   
        
        COLLECTION OF VARIABLE scaling
        {
            MEMBERS
            {
                ADD RANGE_UNITS, deviceVariables[0].DIGITAL_UNITS, [range_units], [range_units_help];
            } 
        }
        
    }
    
}


VARIABLE dummy_variable_32
{
    LABEL "Not used";
    HELP "";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (4)
    {
        DISPLAY_FORMAT  "7d";
    }
}

/*
 * DEVICE SPECIFIC VARIABLES
 */

VARIABLE v_StartTest
{
    LABEL "Command";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}
 

// Error Log variables 
VARIABLE v_1003_00_error_log_count
{
    LABEL "Number of errors";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_01_error1
{
    LABEL "Error 1";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_02_error2
{
    LABEL "Error 2";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_03_error3
{
    LABEL "Error 3";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_04_error4
{
    LABEL "Error 4";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_05_error5
{
    LABEL "Error 5";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_06_error6
{
    LABEL "Error 6";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_07_error7
{
    LABEL "Error 7";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_08_error8
{
    LABEL "Error 8";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_09_error9
{
    LABEL "Error 9";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_1003_10_error10
{
    LABEL "Error 10";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}
// End Error log variables


// Diagnsotic log variables
VARIABLE v_2500_05_diagnostic_log_count
{
    LABEL "Diagnostic log count";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT  "7d";
    }
}


VARIABLE v_2500_07_diagnostic_log1
{
    LABEL "Diagnostic log 1";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log2
{
    LABEL "Diagnostic log 2";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log3
{
    LABEL "Diagnostic log 3";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log4
{
    LABEL "Diagnostic log 4";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log5
{
    LABEL "Diagnostic log 5";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log6
{
    LABEL "Diagnostic log 6";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log7
{
    LABEL "Diagnostic log 7";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log8
{
    LABEL "Diagnostic log 8";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log9
{
    LABEL "Diagnostic log 9";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_2500_07_diagnostic_log10
{
    LABEL "Diagnostic log 10";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "7d";
    }
}

// ## Status Identification variable ##
VARIABLE v_1018_05_SoftwareID     
{
    LABEL "Software ID";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (14);
}

VARIABLE v_2263_01_SoftwareVersion
{
    LABEL "Software version";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (4)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_ManufacturerName
{
    LABEL "Manufacturer name";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (14);
}
 
VARIABLE v_1008_00_Manufacturer_Device_Type
{
    LABEL "Device name";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (14);
}
  
VARIABLE v_1018_04_PCB_Number
{
    LABEL "PCB number";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (4)
    {
        DISPLAY_FORMAT  "7d";
    }
}
// END Status Identification variable


// Last PST status
VARIABLE v_2500_02_Last_PST_Status
{
    LABEL "Last PST status";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "d";
    }
} 
VARIABLE v_2500_04_Last_FST_Status
{
    LABEL "Last FST status";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "d";
    }
} 
VARIABLE v_2510_01_Last_SOT_Status
{
    LABEL "Last SOT status";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "d";
    }
} 
VARIABLE v_2700_02_ESD_Line_Power_Status
{
    LABEL "ESD line power status";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "d";
    }
} 
VARIABLE v_ValveTestService
{
    LABEL "Valve test service";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2)
    {
        DISPLAY_FORMAT  "d";
    }
}  


// ## END BAISC PARAMETERS ##

// ## START ADVANCED PARAMETERS ##



// END ADVANCED PARAMETERS


 /*
 * DEVICE SPECIFIC COMMANDS
 */

 
 
// ## ERROR LOG ##
// COMMAND 130
COMMAND f_read_ErrorLog
{
    NUMBER 130;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status,
            v_1003_00_error_log_count,
            v_1003_01_error1,v_1003_02_error2,v_1003_03_error3,v_1003_04_error4,v_1003_05_error5,
            v_1003_06_error6,v_1003_07_error7,v_1003_08_error8,v_1003_09_error9,v_1003_10_error10
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}

// ## DIAGNOSTIC LOG ##
// COMMAND 131
COMMAND f_read_DiagnosticLog
{
    NUMBER 131;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status,
            v_2500_05_diagnostic_log_count,
            v_2500_07_diagnostic_log1,v_2500_07_diagnostic_log2,v_2500_07_diagnostic_log3,v_2500_07_diagnostic_log4,v_2500_07_diagnostic_log5,
            v_2500_07_diagnostic_log6,v_2500_07_diagnostic_log7,v_2500_07_diagnostic_log8,v_2500_07_diagnostic_log9,v_2500_07_diagnostic_log10
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}

// COMMAND 139
COMMAND f_read_StatusIdentification_SoftwareVersion
{
    NUMBER 139;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status, 
            v_2263_01_SoftwareVersion
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}

// COMMAND 140
COMMAND f_read_StatusIdentification_SoftwareID 
{
    NUMBER 140;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status, 
            v_1018_05_SoftwareID
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}

// COMMAND 141
COMMAND f_read_StatusIdentification_Manufacture
{
    NUMBER 141;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status, 
            v_ManufacturerName
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}

// COMMAND 142 


// COMMAND 143
COMMAND f_read_StatusIdentification_Device_Type
{
    NUMBER 143;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status, 
            v_1008_00_Manufacturer_Device_Type
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}

// COMMAND 144
COMMAND f_read_StatusIdentification_PCB_Number
{
    NUMBER 144;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status, 
      v_1018_04_PCB_Number
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}


// COMMAND 159
COMMAND f_read_LiveStatus_Last_test_information
{
    NUMBER 159;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status,
            dummy_variable_32, // Reserved for PST Time
            dummy_variable_32, // Reserved for PST Date
            v_2500_02_Last_PST_Status,
            dummy_variable_32, // Reserved for FST Time
            dummy_variable_32, // Reserved for FST Date
            v_2500_04_Last_FST_Status,
            dummy_variable_32, // Reserved for SOT Time
            dummy_variable_32, // Reserved for SOT Date
            v_2510_01_Last_SOT_Status
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}

// COMMAND 160
COMMAND f_read_LiveStatus_Live_test_information
{
    NUMBER 160;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY 
        {
            response_code, device_status,
            v_2700_02_ESD_Line_Power_Status,
            v_ValveTestService
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}
      
// COMMAND 211
COMMAND f_write_v_StartTest
{
    NUMBER 211;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {
            v_StartTest
        }
        REPLY 
        {
            response_code, device_status
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,      [no_command_specific_errors];
    }
}     


// ## METHODS ##
METHOD method_StartPST
{
    LABEL "Start PST";
    DEFINITION
    {
       char status[STATUS_SIZE];
       v_StartTest = 1; // PST
       send(211, status);
    }

}

METHOD method_StartFST
{
    LABEL "Start FST";
    DEFINITION
    {
       char status[STATUS_SIZE];
       v_StartTest = 2; // FST
       send(211, status);
    }

}

METHOD method_StartSOT
{
    LABEL "Start SOT";
    DEFINITION
    {
       char status[STATUS_SIZE];
       v_StartTest = 3; // SOT
       send(211, status);
    }

}

METHOD method_AbortTest
{
    LABEL "Abort test";
    DEFINITION
    {
       char status[STATUS_SIZE];
       v_StartTest = 7; // Abort test
       send(211, status);
    }

}

METHOD method_StartRefPST
{
    LABEL "Start reference PST";
    DEFINITION
    {
       char status[STATUS_SIZE];
       v_StartTest = 8; // PST
       send(211, status);
    }

}

METHOD method_StartRefFST
{
    LABEL "Start reference FST";
    DEFINITION
    {
       char status[STATUS_SIZE];
       v_StartTest = 9; // FST
       send(211, status);
    }

}

METHOD method_StartRefSOT
{
    LABEL "Start reference SOT";
    DEFINITION
    {
       char status[STATUS_SIZE];
       v_StartTest = 10; // SOT
       send(211, status);
    }

}

// MENU STRUCTURE

 // Rod menu
MENU root_menu
{
    LABEL [bus_devices];
    ITEMS
    {
        menu_statusLive,
        menu_statusIdentification,     
        menu_Error,
        menu_Commands
    }
}


// STATUS MENU
MENU menu_statusLive
{
    LABEL "Live status";
    ITEMS
    {
     
        PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),      
        PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),
        SV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),
        TV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),
        QV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),
        v_2500_02_Last_PST_Status (DISPLAY_VALUE, READ_ONLY),
        v_2500_04_Last_FST_Status (DISPLAY_VALUE, READ_ONLY),
        v_2510_01_Last_SOT_Status (DISPLAY_VALUE, READ_ONLY),
        v_2700_02_ESD_Line_Power_Status (DISPLAY_VALUE, READ_ONLY),
        v_ValveTestService (DISPLAY_VALUE, READ_ONLY)
   
    }
}

MENU menu_statusIdentification
{
    LABEL "Identification";
    ITEMS
    {
       v_ManufacturerName (DISPLAY_VALUE, READ_ONLY), // Variable 
       v_1008_00_Manufacturer_Device_Type (DISPLAY_VALUE, READ_ONLY),     // Variable
       v_2263_01_SoftwareVersion (DISPLAY_VALUE, READ_ONLY), // Variable
       v_1018_05_SoftwareID (DISPLAY_VALUE, READ_ONLY),      // Variable
       v_1018_04_PCB_Number (DISPLAY_VALUE, READ_ONLY),                // Variable
       tag (DISPLAY_VALUE),
       longTag (DISPLAY_VALUE),
       descriptor (DISPLAY_VALUE),
       message (DISPLAY_VALUE),
       date (DISPLAY_VALUE)
    }
}

// Error menu
MENU menu_Error
{
    LABEL "Error";
    ITEMS
    {
        menu_SystemErrors,    // menu        
        menu_DiagnosticErrors // menu
    }
}
// System errors
MENU menu_SystemErrors
{
    LABEL "System errors";
    ITEMS
    {
       v_1003_00_error_log_count,   // Variable
       v_1003_01_error1,        // Variable
       v_1003_02_error2,        // Variable
       v_1003_03_error3,        // Variable
       v_1003_04_error4,        // Variable
       v_1003_05_error5,        // Variable
       v_1003_06_error6,        // Variable
       v_1003_07_error7,        // Variable
       v_1003_08_error8,        // Variable
       v_1003_09_error9,        // Variable
       v_1003_10_error10        // Variable

    }
}

// System errors
MENU menu_DiagnosticErrors
{
    LABEL "Diagnostic errors";
    ITEMS
    {
       v_2500_05_diagnostic_log_count,   // Variable
       v_2500_07_diagnostic_log1,        // Variable
       v_2500_07_diagnostic_log2,        // Variable
       v_2500_07_diagnostic_log3,        // Variable
       v_2500_07_diagnostic_log4,        // Variable
       v_2500_07_diagnostic_log5,        // Variable
       v_2500_07_diagnostic_log6,        // Variable
       v_2500_07_diagnostic_log7,        // Variable
       v_2500_07_diagnostic_log8,        // Variable
       v_2500_07_diagnostic_log9,        // Variable
       v_2500_07_diagnostic_log10        // Variable

    }
} 

MENU menu_Commands
{
    LABEL "Commands";
    ITEMS
    {
      method_StartPST,
      method_StartFST,
      method_StartSOT,
      method_AbortTest,
      method_StartRefPST,
      method_StartRefFST,
      method_StartRefSOT
    }
}