
/*
 * PRIMARY VARIABLE
 * Dynamic Variables Configuration
 */
VARIABLE v_controlloop_Value
{
    LABEL "Control loop value";
//    HELP [digital_value_pressure_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_Unit
{
    LABEL "Control loop Unit";
    HANDLING READ;
    TYPE ENUMERATED
    {
        { 39,  [mA],	   [milliamperes_help] }
    }
}

VARIABLE v_controlloop_Family
{
    LABEL "Control loop fmly";
    HELP [device_family_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE ENUMERATED
    {
        /*
         * We have declared that the pressure device variable supports the Pressure Family,
         * however, this DD is not complete because there are no Pressure Family commands in it
         */
        DEVICE_VARIABLE_FAMILY_CODE(5)      // This is the macro from above macros.h
    }
}

VARIABLE v_controlloop_Classification
{
    LABEL "Control loop Class";
    HELP [classification_help];
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        DEVICE_VARIABLE_CLASSIFICATION_CODE(65)
    }
}

VARIABLE v_controlloop_PDQ
{
    LABEL "Control loop PDQ";
    HELP [process_data_quality_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        {0 , process_data_status(0)},
        {1 , process_data_status(1)},
        {2 , process_data_status(2)},
        {3 , process_data_status(3)}

        // PROCESS_DATA_STATUS_CODES      // if preferred, use this macro */         
    }
}

VARIABLE v_controlloop_LS
{
    LABEL "Control loop LS";
    HELP [limit_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        LIMIT_STATUS_CODES
    }
}

VARIABLE v_controlloop_Status
{
    LABEL "Control loop Fmly stat";
    HELP [family_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
        { 0x08, device_family_status(0x08), MORE }
    }
}

VARIABLE v_controlloop_USL
{
    LABEL "Control loop upper sensor limit";
    HELP [upper_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_LSL
{
    LABEL "Control loop lower sensor limit";
    HELP [lower_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_MinimumSpan
{
    LABEL "Control loop Min span";
//    HELP [minimum_span_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_DampingValue
{
    LABEL "Control loop Danmping value";
    HELP  [seconds_damping_value_pressure_help];
    // You will probably add a write command for this later
    // Usualy command 34 for Write Primary Variable Damping Value
    HANDLING READ;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE v_controlloop_SerialNumber
{
    LABEL [sensor_serial_number];
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_controlloop_TrimSupport
{
    LABEL "Control loop Trim support";
    HELP [trim_support_help];
    HANDLING READ;
    TYPE ENUMERATED (1)
    {
        TRIM_POINT_CODE(1),   // Lower Trim Point Supported  
        TRIM_POINT_CODE(2),   // Upper Trim Point Supported
        TRIM_POINT_CODE(3)    // Lower and Upper Trim Point Supported
    }
}

VARIABLE v_controlloop_LowerTrimPoint
{
    LABEL "Control loop Lower trim";
    HELP [lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_UpperTrimPoint
{
    LABEL "Control loop Upper trim";
    HELP [upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_MinimumLTP
{
    LABEL "Min lower trim";
    HELP [minimum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_MaximumLTP
{
    LABEL "Max lower trim";
    HELP [maximum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_MinimumUTP
{
    LABEL "Min upper trim";
    HELP [minimum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_MaximumUTP
{
    LABEL "Max upper trim";
    HELP [maximum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_controlloop_MinimumTrimDiff
{
    LABEL "Min trim diff";
    HELP [minimum_trim_diff_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

/* 
 * This is the minimum set of members that any device variable collection must have 
 */
COLLECTION OF VARIABLE collection_controlloop
{
    LABEL "Control Loop";
    //HELP [pressure_help];
    MEMBERS
    {   
        // Sensor Correction Information
        DIGITAL_VALUE,              v_controlloop_Value,         [blank],                [digital_value_help];
        DIGITAL_UNITS,              v_controlloop_Unit,          [units],                [digital_units_help];
        DATA_QUALITY,               v_controlloop_PDQ,           [process_data_quality], [process_data_quality_help];
        LIMIT_STATUS,               v_controlloop_LS,            [limit_status],         [limit_status_help];
        DEVICE_FAMILY_STATUS,       v_controlloop_Status,        [family_status],        [family_status_help];

        CLASSIFICATION,             v_controlloop_Classification,[classification],       [classification_help];
        DEVICE_FAMILY,              v_controlloop_Family,        [device_family],        [device_family_help];

        UPPER_SENSOR_LIMIT,         v_controlloop_USL,           [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         v_controlloop_LSL,           [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               v_controlloop_MinimumSpan,   [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              v_controlloop_DampingValue,  [damping_value],        [seconds_damping_value_help];

        // Device Information
        SENSOR_SERIAL_NUMBER,       v_controlloop_SerialNumber,  [sensor_serial_number], [sensor_serial_number_help];

        // Calibration Information
        TRIM_POINT_UNITS,           v_controlloop_Unit,          [trim_unit],            [sensor_trim_unit_help];
        LOWER_TRIM_POINT,           v_controlloop_LowerTrimPoint,[lower_trim],           [lower_trim_help];
        UPPER_TRIM_POINT,           v_controlloop_UpperTrimPoint,[upper_trim],           [upper_trim_help];
        TRIM_POINT_SUPPORT,         v_controlloop_TrimSupport,   [trim_support],         [trim_support_help];
        MINIMUM_LOWER_TRIM_POINT,   v_controlloop_MinimumLTP,    [minimum_lower_trim],   [minimum_lower_trim_help];
        MAXIMUM_LOWER_TRIM_POINT,   v_controlloop_MaximumLTP,    [maximum_lower_trim],   [maximum_lower_trim_help];
        MINIMUM_UPPER_TRIM_POINT,   v_controlloop_MinimumUTP,    [minimum_upper_trim],   [minimum_upper_trim_help];
        MAXIMUM_UPPER_TRIM_POINT,   v_controlloop_MaximumUTP,    [maximum_upper_trim],   [maximum_upper_trim_help];
        MINIMUM_TRIM_DIFFERENTIAL,  v_controlloop_MinimumTrimDiff,[minimum_trim_diff],   [minimum_trim_diff_help];
    }
}
/*
 * PRIMARY VARIABLE END
*/

/*
 * SECONDARY VARIABLE
 * Dynamic Variables Configuration
 */
VARIABLE v_transmitterloop_Value
{
    LABEL "Transmitter loop value";
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_Unit
{
    LABEL "Transmitter loop Unit";
    HANDLING READ;
    TYPE ENUMERATED
    {
        { 39,  [mA],	   [milliamperes_help] }
    }
}


VARIABLE v_transmitterloop_Family
{
    LABEL "Transmitter loop fmly";
    HELP [device_family_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE ENUMERATED
    {
        /*
         * We have declared that the pressure device variable supports the Pressure Family,
         * however, this DD is not complete because there are no Pressure Family commands in it
         */
        DEVICE_VARIABLE_FAMILY_CODE(5)      // This is the macro from above macros.h
    }
}

VARIABLE v_transmitterloop_Classification
{
    LABEL "Transmitter loop Class";
    HELP [classification_help];
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        DEVICE_VARIABLE_CLASSIFICATION_CODE(65)
    }
}

VARIABLE v_transmitterloop_PDQ
{
    LABEL "Transmitter loop PDQ";
    HELP [process_data_quality_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        {0 , process_data_status(0)},
        {1 , process_data_status(1)},
        {2 , process_data_status(2)},
        {3 , process_data_status(3)}

        // PROCESS_DATA_STATUS_CODES      // if preferred, use this macro */         
    }
}

VARIABLE v_transmitterloop_LS
{
    LABEL "Transmitter loop LS";
    HELP [limit_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        LIMIT_STATUS_CODES
    }
}

VARIABLE v_transmitterloop_Status
{
    LABEL "Transmitter loop Fmly stat";
    HELP [family_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
        { 0x08, device_family_status(0x08), MORE }
    }
}

VARIABLE v_transmitterloop_USL
{
    LABEL "Transmitter loop upper sensor limit";
    HELP [upper_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_LSL
{
    LABEL "Transmitter loop lower sensor limit";
    HELP [lower_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_MinimumSpan
{
    LABEL "Transmitter loop Min span";
//    HELP [minimum_span_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_DampingValue
{
    LABEL "Transmitter loop Danmping value";
    HELP  [seconds_damping_value_pressure_help];
    // You will probably add a write command for this later
    // Usualy command 34 for Write Primary Variable Damping Value
    HANDLING READ;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE v_transmitterloop_SerialNumber
{
    LABEL [sensor_serial_number];
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_transmitterloop_TrimSupport
{
    LABEL "Transmitter loop Trim support";
    HELP [trim_support_help];
    HANDLING READ;
    TYPE ENUMERATED (1)
    {
        TRIM_POINT_CODE(1),   // Lower Trim Point Supported  
        TRIM_POINT_CODE(2),   // Upper Trim Point Supported
        TRIM_POINT_CODE(3)    // Lower and Upper Trim Point Supported
    }
}

VARIABLE v_transmitterloop_LowerTrimPoint
{
    LABEL "Transmitter loop Lower trim";
    HELP [lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_UpperTrimPoint
{
    LABEL "Transmitter loop Upper trim";
    HELP [upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_MinimumLTP
{
    LABEL "Min lower trim";
    HELP [minimum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_MaximumLTP
{
    LABEL "Max lower trim";
    HELP [maximum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_MinimumUTP
{
    LABEL "Min upper trim";
    HELP [minimum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_MaximumUTP
{
    LABEL "Max upper trim";
    HELP [maximum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_transmitterloop_MinimumTrimDiff
{
    LABEL "Min trim diff";
    HELP [minimum_trim_diff_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}


COLLECTION OF VARIABLE collection_transmitterloop
{
    LABEL "Transmitter Loop";
    //HELP [pressure_help];
    MEMBERS
    {   
        // Sensor Correction Information
        DIGITAL_VALUE,              v_transmitterloop_Value,     [blank],                [digital_value_help];
        DIGITAL_UNITS,              v_transmitterloop_Unit,      [units],                [digital_units_help];
        DATA_QUALITY,               v_transmitterloop_PDQ,           [process_data_quality], [process_data_quality_help];
        LIMIT_STATUS,               v_transmitterloop_LS,            [limit_status],         [limit_status_help];
        DEVICE_FAMILY_STATUS,       v_transmitterloop_Status,        [family_status],        [family_status_help];

        CLASSIFICATION,             v_transmitterloop_Classification,[classification],       [classification_help];
        DEVICE_FAMILY,              v_transmitterloop_Family,        [device_family],        [device_family_help];

        UPPER_SENSOR_LIMIT,         v_transmitterloop_USL,           [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         v_transmitterloop_LSL,           [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               v_transmitterloop_MinimumSpan,   [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              v_transmitterloop_DampingValue,  [damping_value],        [seconds_damping_value_help];

        // Device Information
        SENSOR_SERIAL_NUMBER,       v_transmitterloop_SerialNumber,  [sensor_serial_number], [sensor_serial_number_help];

        // Calibration Information
        TRIM_POINT_UNITS,           v_transmitterloop_Unit,          [trim_unit],            [sensor_trim_unit_help];
        LOWER_TRIM_POINT,           v_transmitterloop_LowerTrimPoint,[lower_trim],           [lower_trim_help];
        UPPER_TRIM_POINT,           v_transmitterloop_UpperTrimPoint,[upper_trim],           [upper_trim_help];
        TRIM_POINT_SUPPORT,         v_transmitterloop_TrimSupport,   [trim_support],         [trim_support_help];
        MINIMUM_LOWER_TRIM_POINT,   v_transmitterloop_MinimumLTP,    [minimum_lower_trim],   [minimum_lower_trim_help];
        MAXIMUM_LOWER_TRIM_POINT,   v_transmitterloop_MaximumLTP,    [maximum_lower_trim],   [maximum_lower_trim_help];
        MINIMUM_UPPER_TRIM_POINT,   v_transmitterloop_MinimumUTP,    [minimum_upper_trim],   [minimum_upper_trim_help];
        MAXIMUM_UPPER_TRIM_POINT,   v_transmitterloop_MaximumUTP,    [maximum_upper_trim],   [maximum_upper_trim_help];
        MINIMUM_TRIM_DIFFERENTIAL,  v_transmitterloop_MinimumTrimDiff,[minimum_trim_diff],   [minimum_trim_diff_help];
    }
}

/*
 * TERTIARY VARIABLE
 * Dynamic Variables Configuration
 */
VARIABLE v_position_Value
{
    LABEL "Position";
//    HELP [digital_value_pressure_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_Unit
{
    LABEL "Position loop Unit";
    HANDLING READ;
    TYPE ENUMERATED
    {
        { 0x07,   [bar],                  [bars_help]}
    }
}


VARIABLE v_position_Family
{
    LABEL "Position loop fmly";
    HELP [device_family_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE ENUMERATED
    {
        /*
         * We have declared that the pressure device variable supports the Pressure Family,
         * however, this DD is not complete because there are no Pressure Family commands in it
         */
        DEVICE_VARIABLE_FAMILY_CODE(5)      // This is the macro from above macros.h
    }
}

VARIABLE v_position_Classification
{
    LABEL "Position loop Class";
    HELP [classification_help];
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        DEVICE_VARIABLE_CLASSIFICATION_CODE(65)
    }
}

VARIABLE v_position_PDQ
{
    LABEL "Position loop PDQ";
    HELP [process_data_quality_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        {0 , process_data_status(0)},
        {1 , process_data_status(1)},
        {2 , process_data_status(2)},
        {3 , process_data_status(3)}

        // PROCESS_DATA_STATUS_CODES      // if preferred, use this macro */         
    }
}

VARIABLE v_position_LS
{
    LABEL "Position loop LS";
    HELP [limit_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        LIMIT_STATUS_CODES
    }
}

VARIABLE v_position_Status
{
    LABEL "Position loop Fmly stat";
    HELP [family_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
        { 0x08, device_family_status(0x08), MORE }
    }
}

VARIABLE v_position_USL
{
    LABEL "Position loop upper sensor limit";
    HELP [upper_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_LSL
{
    LABEL "Position loop lower sensor limit";
    HELP [lower_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_MinimumSpan
{
    LABEL "Position loop Min span";
//    HELP [minimum_span_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_DampingValue
{
    LABEL "Position loop Danmping value";
    HELP  [seconds_damping_value_pressure_help];
    // You will probably add a write command for this later
    // Usualy command 34 for Write Primary Variable Damping Value
    HANDLING READ;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE v_position_SerialNumber
{
    LABEL [sensor_serial_number];
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_position_TrimSupport
{
    LABEL "Position loop Trim support";
    HELP [trim_support_help];
    HANDLING READ;
    TYPE ENUMERATED (1)
    {
        TRIM_POINT_CODE(1),   // Lower Trim Point Supported  
        TRIM_POINT_CODE(2),   // Upper Trim Point Supported
        TRIM_POINT_CODE(3)    // Lower and Upper Trim Point Supported
    }
}

VARIABLE v_position_LowerTrimPoint
{
    LABEL "Position loop Lower trim";
    HELP [lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_UpperTrimPoint
{
    LABEL "Position loop Upper trim";
    HELP [upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_MinimumLTP
{
    LABEL "Min lower trim";
    HELP [minimum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_MaximumLTP
{
    LABEL "Max lower trim";
    HELP [maximum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_MinimumUTP
{
    LABEL "Min upper trim";
    HELP [minimum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_MaximumUTP
{
    LABEL "Max upper trim";
    HELP [maximum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_position_MinimumTrimDiff
{
    LABEL "Min trim diff";
    HELP [minimum_trim_diff_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}


COLLECTION OF VARIABLE collection_position
{
    LABEL "Transmitter Loop";
    //HELP [pressure_help];
    MEMBERS
    {   
        // Sensor Correction Information
        DIGITAL_VALUE,              v_position_Value,     [blank],                [digital_value_help];
        DIGITAL_UNITS,              v_position_Unit,      [units],                [digital_units_help];
        DATA_QUALITY,               v_position_PDQ,           [process_data_quality], [process_data_quality_help];
        LIMIT_STATUS,               v_position_LS,            [limit_status],         [limit_status_help];
        DEVICE_FAMILY_STATUS,       v_position_Status,        [family_status],        [family_status_help];

        CLASSIFICATION,             v_position_Classification,[classification],       [classification_help];
        DEVICE_FAMILY,              v_position_Family,        [device_family],        [device_family_help];

        UPPER_SENSOR_LIMIT,         v_position_USL,           [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         v_position_LSL,           [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               v_position_MinimumSpan,   [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              v_position_DampingValue,  [damping_value],        [seconds_damping_value_help];

        // Device Information
        SENSOR_SERIAL_NUMBER,       v_position_SerialNumber,  [sensor_serial_number], [sensor_serial_number_help];

        // Calibration Information
        TRIM_POINT_UNITS,           v_position_Unit,          [trim_unit],            [sensor_trim_unit_help];
        LOWER_TRIM_POINT,           v_position_LowerTrimPoint,[lower_trim],           [lower_trim_help];
        UPPER_TRIM_POINT,           v_position_UpperTrimPoint,[upper_trim],           [upper_trim_help];
        TRIM_POINT_SUPPORT,         v_position_TrimSupport,   [trim_support],         [trim_support_help];
        MINIMUM_LOWER_TRIM_POINT,   v_position_MinimumLTP,    [minimum_lower_trim],   [minimum_lower_trim_help];
        MAXIMUM_LOWER_TRIM_POINT,   v_position_MaximumLTP,    [maximum_lower_trim],   [maximum_lower_trim_help];
        MINIMUM_UPPER_TRIM_POINT,   v_position_MinimumUTP,    [minimum_upper_trim],   [minimum_upper_trim_help];
        MAXIMUM_UPPER_TRIM_POINT,   v_position_MaximumUTP,    [maximum_upper_trim],   [maximum_upper_trim_help];
        MINIMUM_TRIM_DIFFERENTIAL,  v_position_MinimumTrimDiff,[minimum_trim_diff],   [minimum_trim_diff_help];
    }
}

/*
 * QUATERNARY VARIABLE
 * Dynamic Variables Configuration
 */
VARIABLE v_pressure_Value
{
    LABEL "Pressure";
//    HELP [digital_value_pressure_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_Unit
{
    LABEL "Pressure loop Unit"; // [pressure_value_unit];
//    HELP [digital_units_pressure_help];
    HANDLING READ;
    TYPE ENUMERATED
    {
        { 57,   [percent],                [percent_help] }
    }
}


VARIABLE v_pressure_Family
{
    LABEL "Pressure loop fmly";
    HELP [device_family_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE ENUMERATED
    {
        /*
         * We have declared that the pressure device variable supports the Pressure Family,
         * however, this DD is not complete because there are no Pressure Family commands in it
         */
        DEVICE_VARIABLE_FAMILY_CODE(5)      // This is the macro from above macros.h
    }
}

VARIABLE v_pressure_Classification
{
    LABEL "Pressure loop Class";
    HELP [classification_help];
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        DEVICE_VARIABLE_CLASSIFICATION_CODE(65)
    }
}

VARIABLE v_pressure_PDQ
{
    LABEL "Pressure loop PDQ";
    HELP [process_data_quality_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        {0 , process_data_status(0)},
        {1 , process_data_status(1)},
        {2 , process_data_status(2)},
        {3 , process_data_status(3)}

        // PROCESS_DATA_STATUS_CODES      // if preferred, use this macro */         
    }
}

VARIABLE v_pressure_LS
{
    LABEL "Pressure loop LS";
    HELP [limit_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        LIMIT_STATUS_CODES
    }
}

VARIABLE v_pressure_Status
{
    LABEL "Pressure loop Fmly stat";
    HELP [family_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
        { 0x08, device_family_status(0x08), MORE }
    }
}

VARIABLE v_pressure_USL
{
    LABEL "Pressure loop upper sensor limit";
    HELP [upper_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_LSL
{
    LABEL "Pressure loop lower sensor limit";
    HELP [lower_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_MinimumSpan
{
    LABEL "Pressure loop Min span";
//    HELP [minimum_span_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_DampingValue
{
    LABEL "Pressure loop Danmping value";
    HELP  [seconds_damping_value_pressure_help];
    // You will probably add a write command for this later
    // Usualy command 34 for Write Primary Variable Damping Value
    HANDLING READ;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE v_pressure_SerialNumber
{
    LABEL [sensor_serial_number];
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE v_pressure_TrimSupport
{
    LABEL "Pressure loop Trim support";
    HELP [trim_support_help];
    HANDLING READ;
    TYPE ENUMERATED (1)
    {
        TRIM_POINT_CODE(1),   // Lower Trim Point Supported  
        TRIM_POINT_CODE(2),   // Upper Trim Point Supported
        TRIM_POINT_CODE(3)    // Lower and Upper Trim Point Supported
    }
}

VARIABLE v_pressure_LowerTrimPoint
{
    LABEL "Pressure loop Lower trim";
    HELP [lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_UpperTrimPoint
{
    LABEL "Pressure loop Upper trim";
    HELP [upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_MinimumLTP
{
    LABEL "Min lower trim";
    HELP [minimum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_MaximumLTP
{
    LABEL "Max lower trim";
    HELP [maximum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_MinimumUTP
{
    LABEL "Min upper trim";
    HELP [minimum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_MaximumUTP
{
    LABEL "Max upper trim";
    HELP [maximum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE v_pressure_MinimumTrimDiff
{
    LABEL "Min trim diff";
    HELP [minimum_trim_diff_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}


COLLECTION OF VARIABLE collection_pressure
{
    LABEL "Pressure Loop";
    //HELP [pressure_help];
    MEMBERS
    {   
        // Sensor Correction Information
        DIGITAL_VALUE,              v_pressure_Value,     [blank],                [digital_value_help];
        DIGITAL_UNITS,              v_pressure_Unit,      [units],                [digital_units_help];
        DATA_QUALITY,               v_pressure_PDQ,           [process_data_quality], [process_data_quality_help];
        LIMIT_STATUS,               v_pressure_LS,            [limit_status],         [limit_status_help];
        DEVICE_FAMILY_STATUS,       v_pressure_Status,        [family_status],        [family_status_help];

        CLASSIFICATION,             v_pressure_Classification,[classification],       [classification_help];
        DEVICE_FAMILY,              v_pressure_Family,        [device_family],        [device_family_help];

        UPPER_SENSOR_LIMIT,         v_pressure_USL,           [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         v_pressure_LSL,           [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               v_pressure_MinimumSpan,   [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              v_pressure_DampingValue,  [damping_value],        [seconds_damping_value_help];

        // Device Information
        SENSOR_SERIAL_NUMBER,       v_pressure_SerialNumber,  [sensor_serial_number], [sensor_serial_number_help];

        // Calibration Information
        TRIM_POINT_UNITS,           v_pressure_Unit,          [trim_unit],            [sensor_trim_unit_help];
        LOWER_TRIM_POINT,           v_pressure_LowerTrimPoint,[lower_trim],           [lower_trim_help];
        UPPER_TRIM_POINT,           v_pressure_UpperTrimPoint,[upper_trim],           [upper_trim_help];
        TRIM_POINT_SUPPORT,         v_pressure_TrimSupport,   [trim_support],         [trim_support_help];
        MINIMUM_LOWER_TRIM_POINT,   v_pressure_MinimumLTP,    [minimum_lower_trim],   [minimum_lower_trim_help];
        MAXIMUM_LOWER_TRIM_POINT,   v_pressure_MaximumLTP,    [maximum_lower_trim],   [maximum_lower_trim_help];
        MINIMUM_UPPER_TRIM_POINT,   v_pressure_MinimumUTP,    [minimum_upper_trim],   [minimum_upper_trim_help];
        MAXIMUM_UPPER_TRIM_POINT,   v_pressure_MaximumUTP,    [maximum_upper_trim],   [maximum_upper_trim_help];
        MINIMUM_TRIM_DIFFERENTIAL,  v_pressure_MinimumTrimDiff,[minimum_trim_diff],   [minimum_trim_diff_help];
    }
}

ARRAY OF COLLECTION deviceVariables // Do not rename, it will cause an error. (SG)
{
    ELEMENTS
    {
        0, collection_controlloop, [pv];
        1, collection_transmitterloop, [sv];
        2, collection_position, [tv];
        3, collection_pressure, [qv];
    }
}

